summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/xkbcommon/xkbcommon.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/xkbcommon/xkbcommon.h b/include/xkbcommon/xkbcommon.h
index dac14ec..315f590 100644
--- a/include/xkbcommon/xkbcommon.h
+++ b/include/xkbcommon/xkbcommon.h
@@ -172,18 +172,18 @@ xkb_canonicalise_components(struct xkb_component_names *names,
const struct xkb_component_names *old);
/*
* Converts a keysym to a string; will return unknown Unicode codepoints
* as "Ua1b2", and other unknown keysyms as "0xabcd1234".
*/
void
-xkb_keysym_to_string(xkb_keysym_t ks, char *buffer, size_t size);
+xkb_keysym_get_name(xkb_keysym_t ks, char *buffer, size_t size);
/*
* See xkb_keysym_to_string comments: this function will accept any string
* from that function.
*/
xkb_keysym_t
-xkb_string_to_keysym(const char *s);
+xkb_keysym_from_name(const char *s);
/**
* @defgroup ctx XKB contexts
@@ -172,18 +172,18 @@ xkb_canonicalise_components(struct xkb_component_names *names,
const struct xkb_component_names *old);
/*
- * Converts a keysym to a string; will return unknown Unicode codepoints
- * as "Ua1b2", and other unknown keysyms as "0xabcd1234".
+ * Returns the name for a keysym as a string; will return unknown Unicode
+ * codepoints as "Ua1b2", and other unknown keysyms as "0xabcd1234".
*/
void